[Android] build: fix shmdt hack

Victorien Le Couviour--Tuffet git at videolan.org
Tue Oct 23 17:25:42 CEST 2018


vlc-android | branch: master | Victorien Le Couviour--Tuffet <victorien.lecouviour.tuffet at gmail.com> | Sun Sep 23 13:36:43 2018 +0200| [0a3e5d9962fe8930b9326b0b6076075ce4fd681c] | committer: Thomas Guillem

build: fix shmdt hack

> https://code.videolan.org/videolan/vlc-android/commit/0a3e5d9962fe8930b9326b0b6076075ce4fd681c
---

 compile-libvlc.sh | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/compile-libvlc.sh b/compile-libvlc.sh
index 9e65c8398..425e99fc6 100755
--- a/compile-libvlc.sh
+++ b/compile-libvlc.sh
@@ -534,11 +534,13 @@ if [ "${CHROME_OS}" = "1" ];then
     export ac_cv_func_pipe2=no
 fi
 
-if [ ${ANDROID_API} = "21" ] ; then
-    # android-21 has empty sys/shm.h headers that triggers shm detection but it
+if [ ${ANDROID_API} -lt "26" ]; then
+    # android APIs < 26 have empty sys/shm.h headers that triggers shm detection but it
     # doesn't have any shm functions and/or symbols. */
     export ac_cv_header_sys_shm_h=no
-else
+fi
+
+if [ ${ANDROID_API} -lt "21" ] ; then
     # force uselocale using libandroid_support since it's present in libc++
     export ac_cv_func_uselocale=yes
 



More information about the Android mailing list